# -*- coding: utf-8 -*-
"""
dumps:保存内存中的变量
loads:读取已保存的变量到主命名空间（顺便引入numpy、pandas）
type_list:需要保存的变量类型
drop_list:不想保存的变量列表（主要针对jupyter）


Created on Thu Sep  5 14:11:55 2019

@author: karond
"""
import __main__ as _main_module
import pickle
import datetime
import os
import numpy as np
import pandas as pd
import config

type_list = config.type_list
drop_list = config.drop_list
path = config.path


def dumps(name = '',path = path):
    """
    默认保存到：./data_pickle/%Y-%m-%d/%H-%M-%S.pkl
    name:自定义变量保存位置
    path:保存数据的文件夹位置
    """
    if name == '':
        path = os.path.join(path,datetime.datetime.now().strftime('%Y-%m-%d'))
        if not os.path.exists(path):
            os.makedirs(path)
            print('创建'+path)
        path = os.path.join(path,datetime.datetime.now().strftime('%H-%M-%S'))+'.pkl'
    else:
        path = name
    pickl = []
    for i in _main_module.__dict__.copy().items():
        if i[0][0] != '_' and str(type(i[1])).split("'")[1] in type_list and i[0] not in drop_list:
            pickl.append(i)
    try:
        pickl = tuple( pickl )
        f = open(path,'wb')
        pickle.dump(pickl,f)
        f.close()
        print("pickle:"+path)
    except:
          print('pickle ERROR')
def loads(name = '',replace = False,path = path):
    """
    默认读取：./data_pickle/%Y-%m-%d/%H-%M-%S.pkl中最新的文件
    name:自定义变量读取位置
    replace:是否替换已经定义的变量
    path:读取数据的文件夹位置
    """
    try:
        if name == '':
            dir_list = [datetime.datetime.strptime(i,'%Y-%m-%d') for i in os.listdir(path)]
            path = os.path.join(path,max(dir_list).strftime('%Y-%m-%d'))
            dir_list = [datetime.datetime.strptime(i.split('.')[0],'%H-%M-%S') for i in os.listdir(path)]
            path = os.path.join(path,max(dir_list).strftime('%H-%M-%S'))+'.pkl'
        else:
            path = name
        setattr(_main_module,'np',np)
        setattr(_main_module,'pd',pd)
        f = open(path,'rb')
        pickl = pickle.load(f)
        for i in pickl:
            if hasattr(_main_module,i[0]) and replace == False:
                pass
            else:
                print(i[0])
                setattr(_main_module,i[0],i[1])
        print('laod:'+path)
    except:
        print('load ERROR')



"""
dumps:保存内存中的变量
loads:读取已保存的变量到主命名空间（顺便引入numpy、pandas）
type_list:需要保存的变量类型
drop_list:不想保存的变量列表（主要针对jupyter）


Created on Thu Sep  5 14:11:55 2019

@author: karond
"""

__version__ = "0.1.5"
__author__ = 'karond'


from .__vars_pickle import dumps
from .__vars_pickle import loads
from .__config import drop_list
from .__config import type_list


# -*- coding: utf-8 -*-
"""
Created on Thu Sep  5 14:45:27 2019

@author: 10167232
"""

import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="vars_pickle",
    version="0.1.5",
    author="karond",
    author_email="dingyaohui.g@outlook.com",
    description="Save your variable as Rstudio",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/pypa/sampleproject",
    packages=setuptools.find_packages(),
    install_requires = ['pandas','numpy'],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)


# -*- coding: utf-8 -*-
"""
Created on Fri Sep  6 08:27:35 2019

@author: 10167232
"""
path = 'data_pickle'
type_list = ['str','function','pandas.core.frame.DataFrame','pandas.core.series.Series','list','dict','int','float','set','tuple']
drop_list = ['In','Out','var_dic_list','get_ipython','']